mysql.exceptions.server.Trg_No_Definer

Package mysql :: Package exceptions :: Module server :: Class Trg_No_Definer |
[hide private]
[frames] | no frames]

# Class Trg_No_Definer

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Trg_No_Definer

No definer attribute for trigger '%-.64s'.'%-.64s'. The trigger will be activated under the auth orization of the invoker, which may have insufficient privileges. Please recreate the trigger.

(New in 5.0.17.)

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`